# Glossary

## Symbols

| Symbol | Definition | Units | Notes |
|---|---|---|---|
| $\sigma_{bs}$ | differential backscattering cross-section | m<sup>2</sup> |   |
| $\sigma_{b}$ | backscattering cross-section | m<sup>2</sup> | |
| $TS$ | target strength | dB re 1 m<sup>2</sup> |  |
| $s_V$ | volume backscattering coefficient | m<sup>-1</sup> |  |
| $S_V$ | volume backscattering strength | dB re 1 m<sup>-1</sup> |  |
| $s_A$ or $NASC$ | nautical areal backscattering coefficients | m<sup>2</sup>nmi<sup>-2</sup> |  |
| $s_a$ or $ABC$ | areal backscattering coefficient | m<sup>2</sup>m<sup>-2</sup> |  |
| $\rho_a$ | number density of animals | m<sup>-2</sup> |  |
| $\rho_A$ | nautical areal number density | nmi<sup>-2</sup> |  |
| $\rho_B$ | biomass density | kg nmi<sup>-2</sup> |  |
| $B$ | biomass estimates | kg |  |
| $i$ | stratum | |  |
| $\alpha$ | age | year |  |
| $L$ or $\ell$ | length of animal | m or cm |  |
| $s$ | sex of animal | |  |
| $w$ | weight of animal | kg |  |
| $N$ | number of animal samples | |  |
| $x, y$ | geospatial location (latitude, longitude) | degrees |  |
| $x_k, y_k$ | kriging grid location | |  |


## Acronyms
- INPFC: International North Pacific Fisheries Commission
- K-S test: Kolomogorov-Smirnov test


<!-- Glossary of all symbols, indices, and notations used for mathematical equations and variables contained within the `Survey` class object. 


![ text ](images/symbols.jpeg) -->
